Learn R Programming

chlorpromazineR (version 0.2.0)

check_key: Check whether a conversion key is the expected format

Description

chlorpromazineR uses conversion factors stored in a named list of 3 named lists. This verifies that the key is in a usable format, which can be helpful when creating custom keys or modifying included keys.

Usage

check_key(key)

Arguments

key

the key to check

Value

TRUE if the key is valid, otherwise a error is thrown.

See Also

Other key functions: add_key(), trim_key()

Examples

Run this code
# NOT RUN {
check_key(gardner2010)
# }

Run the code above in your browser using DataLab