Learn R Programming

chlorpromazineR (version 0.2.0)

leucht2016: Chlorpromazine equivalent key from Leucht et al. 2016 data

Description

A list of antipsychotics and their chlorpromazine equivalent doses, generated from the following file included with the package: system.file("extdata", "leucht2016.csv", package="chlorpromazineR").

Usage

leucht2016

Arguments

Format

A named list of 3 named lists (1 for each route) and each sub-list contains the conversion factors for each antipsychotic. The 3 top-level lists are named `oral`, `sai`, and `lai` (route), and the lists they contain have names corresponding to the antipsychotic, e.g. `olanzapine`.