Learn R Programming

chlorpromazineR (version 0.2.0)

woods2003: Chlorpromazine equivalent key from Woods 2003 data

Description

A list of antipsychotics and their chlorpromazine equivalent doses, generated from the following file included with the package: system.file("extdata", "woods2003.csv", package="chlorpromazineR").

Usage

woods2003

Arguments

Format

A named list of 3 named lists (1 for each route) and each sub-list contains the conversion factors for each antipsychotic. The 3 top-level lists are named `oral`, `sai`, and `lai` (route), and the lists they contain have names corresponding to the antipsychotic, e.g. `olanzapine`.