Learn R Programming

chlorpromazineR (version 0.2.0)

add_key: Combine 2 keys with base key taking precedence

Description

Use this to combine 2 keys by using the whole "base" key, and adding any antipsychotics from the "added" key that are not in the "base" key.

Usage

add_key(base, added, trim, verbose = TRUE)

Arguments

base

the base key

added

the key from which other antipsychotics are found to add

trim

TRUE to use trim_key on both the base and added key, needed when one does not use the full names (e.g. leucht2016).

verbose

If TRUE, added antipsychotic names will be shown in a message

Value

a merged key

See Also

Other key functions: check_key(), trim_key()

Examples

Run this code
# NOT RUN {
add_key(gardner2010, leucht2016, trim = TRUE)
# }

Run the code above in your browser using DataLab