powered by
Use this to combine 2 keys by using the whole "base" key, and adding any antipsychotics from the "added" key that are not in the "base" key.
add_key(base, added, trim, verbose = TRUE)
the base key
the key from which other antipsychotics are found to add
TRUE to use trim_key on both the base and added key, needed when one does not use the full names (e.g. leucht2016).
If TRUE, added antipsychotic names will be shown in a message
a merged key
Other key functions: check_key(), trim_key()
check_key()
trim_key()
# NOT RUN { add_key(gardner2010, leucht2016, trim = TRUE) # }
Run the code above in your browser using DataLab