check_key: Check whether a conversion key is the expected format
Description
chlorpromazineR uses conversion factors stored in a named list of 3 named
lists. This verifies that the key is in a usable format, which can be helpful
when creating custom keys or modifying included keys.
Usage
check_key(key)
Arguments
key
the key to check
Value
TRUE if the key is valid, otherwise a error is thrown.