A list of antipsychotics and their chlorpromazine equivalent doses, generated from the following file included with the package: system.file("extdata", "gardner2010.csv", package="chlorpromazineR").
gardner2010_withsaiA named list of 3 named lists (1 for each route) and each sub-list contains the conversion factors for each antipsychotic. The 3 top-level lists are named `oral`, `sai`, and `lai` (route), and the lists they contain have names corresponding to the antipsychotic, e.g. `olanzapine`.
The SAI equivalents produced by this key are equivalent to chlorpromazine SAI not oral. They could be manually converted.