For parenteral (sai) and long-acting/depot (lai) antipsychotics, the name
consists of the usual generic name (such as haloperidol) and a second word
describing the formulation (e.g. haloperidol decanoate). Since to_cpz() and
add_key() require exact matches to work properly, removing the second word
may be required, but should be done with care as it can add ambiguity (e.g.
fluphenazine enanthate and decanoate).